==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ConsoleSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsoleSpecFluentImpl<A extends ConsoleSpecFluent<A>> extends BaseFluent<A> implements ConsoleSpecFluent<A>{
  public ConsoleSpecFluentImpl() {
  }
  public ConsoleSpecFluentImpl(ConsoleSpec instance) {
    this.withAuthentication(instance.getAuthentication()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ConsoleAuthenticationBuilder authentication;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAuthentication instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConsoleAuthentication getAuthentication() {
    return this.authentication!=null ?this.authentication.build():null;
  }
  public ConsoleAuthentication buildAuthentication() {
    return this.authentication!=null ?this.authentication.build():null;
  }
  public A withAuthentication(ConsoleAuthentication authentication) {
    _visitables.get("authentication").remove(this.authentication);
    if (authentication!=null){ this.authentication= new ConsoleAuthenticationBuilder(authentication); _visitables.get("authentication").add(this.authentication);} else { this.authentication = null; _visitables.get("authentication").remove(this.authentication); } return (A) this;
  }
  public Boolean hasAuthentication() {
    return this.authentication != null;
  }
  public A withNewAuthentication(String logoutRedirect) {
    return (A)withAuthentication(new ConsoleAuthentication(logoutRedirect));
  }
  public ConsoleSpecFluent.AuthenticationNested<A> withNewAuthentication() {
    return new ConsoleSpecFluentImpl.AuthenticationNestedImpl();
  }
  public ConsoleSpecFluent.AuthenticationNested<A> withNewAuthenticationLike(ConsoleAuthentication item) {
    return new ConsoleSpecFluentImpl.AuthenticationNestedImpl(item);
  }
  public ConsoleSpecFluent.AuthenticationNested<A> editAuthentication() {
    return withNewAuthenticationLike(getAuthentication());
  }
  public ConsoleSpecFluent.AuthenticationNested<A> editOrNewAuthentication() {
    return withNewAuthenticationLike(getAuthentication() != null ? getAuthentication(): new ConsoleAuthenticationBuilder().build());
  }
  public ConsoleSpecFluent.AuthenticationNested<A> editOrNewAuthenticationLike(ConsoleAuthentication item) {
    return withNewAuthenticationLike(getAuthentication() != null ? getAuthentication(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleSpecFluentImpl that = (ConsoleSpecFluentImpl) o;
    if (authentication != null ? !authentication.equals(that.authentication) :that.authentication != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(authentication,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (authentication != null) { sb.append("authentication:"); sb.append(authentication + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class AuthenticationNestedImpl<N> extends ConsoleAuthenticationFluentImpl<ConsoleSpecFluent.AuthenticationNested<N>> implements ConsoleSpecFluent.AuthenticationNested<N>,Nested<N>{
    AuthenticationNestedImpl(ConsoleAuthentication item) {
      this.builder = new ConsoleAuthenticationBuilder(this, item);
    }
    AuthenticationNestedImpl() {
      this.builder = new ConsoleAuthenticationBuilder(this);
    }
    ConsoleAuthenticationBuilder builder;
    public N and() {
      return (N) ConsoleSpecFluentImpl.this.withAuthentication(builder.build());
    }
    public N endAuthentication() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ConsoleSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsoleSpecFluentImpl<A extends ConsoleSpecFluent<A>> extends BaseFluent<A> implements ConsoleSpecFluent<A>{
  public ConsoleSpecFluentImpl() {
  }
  public ConsoleSpecFluentImpl(ConsoleSpec instance) {
    if (instance != null) {
      this.withAuthentication(instance.getAuthentication());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ConsoleAuthenticationBuilder authentication;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAuthentication instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConsoleAuthentication getAuthentication() {
    return this.authentication!=null ?this.authentication.build():null;
  }
  public ConsoleAuthentication buildAuthentication() {
    return this.authentication!=null ?this.authentication.build():null;
  }
  public A withAuthentication(ConsoleAuthentication authentication) {
    _visitables.get("authentication").remove(this.authentication);
    if (authentication!=null){ this.authentication= new ConsoleAuthenticationBuilder(authentication); _visitables.get("authentication").add(this.authentication);} else { this.authentication = null; _visitables.get("authentication").remove(this.authentication); } return (A) this;
  }
  public Boolean hasAuthentication() {
    return this.authentication != null;
  }
  public A withNewAuthentication(String logoutRedirect) {
    return (A)withAuthentication(new ConsoleAuthentication(logoutRedirect));
  }
  public ConsoleSpecFluentImpl.AuthenticationNested<A> withNewAuthentication() {
    return new ConsoleSpecFluentImpl.AuthenticationNestedImpl();
  }
  public ConsoleSpecFluentImpl.AuthenticationNested<A> withNewAuthenticationLike(ConsoleAuthentication item) {
    return new ConsoleSpecFluentImpl.AuthenticationNestedImpl(item);
  }
  public ConsoleSpecFluentImpl.AuthenticationNested<A> editAuthentication() {
    return withNewAuthenticationLike(getAuthentication());
  }
  public ConsoleSpecFluentImpl.AuthenticationNested<A> editOrNewAuthentication() {
    return withNewAuthenticationLike(getAuthentication() != null ? getAuthentication(): new ConsoleAuthenticationBuilder().build());
  }
  public ConsoleSpecFluentImpl.AuthenticationNested<A> editOrNewAuthenticationLike(ConsoleAuthentication item) {
    return withNewAuthenticationLike(getAuthentication() != null ? getAuthentication(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleSpecFluentImpl that = (ConsoleSpecFluentImpl) o;
    if (!java.util.Objects.equals(authentication, that.authentication)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(authentication,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (authentication != null) { sb.append("authentication:"); sb.append(authentication + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class AuthenticationNestedImpl<N> extends ConsoleAuthenticationFluentImpl<ConsoleSpecFluentImpl.AuthenticationNested<N>> implements ConsoleSpecFluentImpl.AuthenticationNested<N>,Nested<N>{
    AuthenticationNestedImpl(ConsoleAuthentication item) {
      this.builder = new ConsoleAuthenticationBuilder(this, item);
    }
    AuthenticationNestedImpl() {
      this.builder = new ConsoleAuthenticationBuilder(this);
    }
    ConsoleAuthenticationBuilder builder;
    public N and() {
      return (N) ConsoleSpecFluentImpl.this.withAuthentication(builder.build());
    }
    public N endAuthentication() {
      return and();
    }
    
  }
  
}
